==> zio-aws-dynamodb_2.13-5.17.113.1-sources.jar: zio/aws/dynamodb/model/BatchStatementRequest.scala <==
package zio.aws.dynamodb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.dynamodb.model.primitives.{ConsistentRead, PartiQLStatement}
import scala.jdk.CollectionConverters._
final case class BatchStatementRequest(
    statement: PartiQLStatement,
    parameters: Option[Iterable[zio.aws.dynamodb.model.AttributeValue]] = None,
    consistentRead: Option[ConsistentRead] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest = {
    import BatchStatementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
      .builder()
      .statement(PartiQLStatement.unwrap(statement): java.lang.String)
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .optionallyWith(
        consistentRead.map(value =>
          ConsistentRead.unwrap(value): java.lang.Boolean
        )
      )(_.consistentRead)
      .build()
  }
  def asReadOnly: zio.aws.dynamodb.model.BatchStatementRequest.ReadOnly =
    zio.aws.dynamodb.model.BatchStatementRequest.wrap(buildAwsValue())
}
object BatchStatementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dynamodb.model.BatchStatementRequest =
      zio.aws.dynamodb.model.BatchStatementRequest(
        statement,
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        consistentRead.map(value => value)
      )
    def statement: PartiQLStatement
    def parameters: Option[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]]
    def consistentRead: Option[ConsistentRead]
    def getStatement: ZIO[Any, Nothing, PartiQLStatement] =
      ZIO.succeed(statement)
    def getParameters: ZIO[Any, AwsError, List[
      zio.aws.dynamodb.model.AttributeValue.ReadOnly
    ]] = AwsError.unwrapOptionField("parameters", parameters)
    def getConsistentRead: ZIO[Any, AwsError, ConsistentRead] =
      AwsError.unwrapOptionField("consistentRead", consistentRead)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
  ) extends zio.aws.dynamodb.model.BatchStatementRequest.ReadOnly {
    override val statement: PartiQLStatement =
      zio.aws.dynamodb.model.primitives.PartiQLStatement(impl.statement())
    override val parameters
        : Option[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]] = scala
      .Option(impl.parameters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.dynamodb.model.AttributeValue.wrap(item)
        }.toList
      )
    override val consistentRead: Option[ConsistentRead] = scala
      .Option(impl.consistentRead())
      .map(value => zio.aws.dynamodb.model.primitives.ConsistentRead(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
  ): zio.aws.dynamodb.model.BatchStatementRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dynamodb_2.13-5.17.239.1-sources.jar: zio/aws/dynamodb/model/BatchStatementRequest.scala <==
package zio.aws.dynamodb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.dynamodb.model.primitives.{ConsistentRead, PartiQLStatement}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BatchStatementRequest(
    statement: PartiQLStatement,
    parameters: Optional[Iterable[zio.aws.dynamodb.model.AttributeValue]] =
      Optional.Absent,
    consistentRead: Optional[ConsistentRead] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest = {
    import BatchStatementRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
      .builder()
      .statement(PartiQLStatement.unwrap(statement): java.lang.String)
      .optionallyWith(
        parameters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameters)
      .optionallyWith(
        consistentRead.map(value =>
          ConsistentRead.unwrap(value): java.lang.Boolean
        )
      )(_.consistentRead)
      .build()
  }
  def asReadOnly: zio.aws.dynamodb.model.BatchStatementRequest.ReadOnly =
    zio.aws.dynamodb.model.BatchStatementRequest.wrap(buildAwsValue())
}
object BatchStatementRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dynamodb.model.BatchStatementRequest =
      zio.aws.dynamodb.model.BatchStatementRequest(
        statement,
        parameters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        consistentRead.map(value => value)
      )
    def statement: PartiQLStatement
    def parameters
        : Optional[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]]
    def consistentRead: Optional[ConsistentRead]
    def getStatement: ZIO[Any, Nothing, PartiQLStatement] =
      ZIO.succeed(statement)
    def getParameters: ZIO[Any, AwsError, List[
      zio.aws.dynamodb.model.AttributeValue.ReadOnly
    ]] = AwsError.unwrapOptionField("parameters", parameters)
    def getConsistentRead: ZIO[Any, AwsError, ConsistentRead] =
      AwsError.unwrapOptionField("consistentRead", consistentRead)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
  ) extends zio.aws.dynamodb.model.BatchStatementRequest.ReadOnly {
    override val statement: PartiQLStatement =
      zio.aws.dynamodb.model.primitives.PartiQLStatement(impl.statement())
    override val parameters
        : Optional[List[zio.aws.dynamodb.model.AttributeValue.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.dynamodb.model.AttributeValue.wrap(item)
          }.toList
        )
    override val consistentRead: Optional[ConsistentRead] =
      zio.aws.core.internal
        .optionalFromNullable(impl.consistentRead())
        .map(value => zio.aws.dynamodb.model.primitives.ConsistentRead(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.dynamodb.model.BatchStatementRequest
  ): zio.aws.dynamodb.model.BatchStatementRequest.ReadOnly = new Wrapper(impl)
}
